@@ -21,8 +21,8 @@ __plugin_meta__ = PluginMetadata(
     description="一键导入课表、查看课表、提醒上课、查询课程",
     usage="课表帮助",
 )
-mytable = on_regex(r'^(小爱|我的|本周|下周)(课表)', priority=1, block=False)
-newtable = on_command('导入课表', priority=1, block=False, aliases={'创建课表'})
+mytable = on_regex(r'^(小爱|我的|本周|下周)(课表)', priority=20, block=False)
+newtable = on_command('导入课表', priority=20, block=False, aliases={'创建课表'})
 tablehelp = on_command("课表帮助", priority=20, block=True,
                        aliases={"课表介绍", "课表怎么用"})
 someday_table = on_regex(
@@ -33,6 +33,8 @@ add_alock_morningcalss = on_regex(
     r'^(订阅|提醒)早八', priority=20, block=True)
 remove_alock_someday = on_regex(
     r'^(取消)(订阅|提醒)((周|星期)(一|二|三|四|五|六|日|天))(课程|课表)', priority=20, block=True)
+remove_alock_morningclass=on_command("取消订阅早八",priority=20,block=False,aliases={"取消提醒早八"})
+renew_table=on_command("更新本地课表",priority=20,block=False,aliases={'更新课表'})
 
 
 @tablehelp.handle()
@@ -59,13 +61,13 @@ async def _(bot: Bot, event: MessageEvent, key: str = RegexMatched()):
         await mytable.finish('你还没有导入课表，发送\\导入课表来导入吧！', at_sender=True)
 # 导入课表
 
-real_url = "寄"
+res_url = "寄"
 
 
 def geturl(response):
-    global real_url
-    real_url = str(response.url) if re.match(
-        real_url_re, response.url) else real_url
+    global res_url
+    res_url = str(response.url) if re.match(
+        res_url_re, response.url) else res_url
 
 
 @newtable.got('key', '请发送小爱课程表导出的链接，发送\\取消以退出')  # 导入课表
@@ -77,10 +79,10 @@ async def _(matcher: Matcher, bot: Bot, event: MessageEvent, key: str = ArgStr()
         async with get_new_page(viewport={"width": 1000, "height": 1200}) as page:
             page.on("response", lambda response: geturl(response))
             await page.goto(url, wait_until='networkidle')
-            global real_url
-            log_debug("response.url", real_url)
+            global res_url
+            log_debug("response.url", res_url)
             async with httpx.AsyncClient() as r:
-                res = await r.get(real_url)
+                res = await r.get(res_url)
                 usertable.update({uid: res.json()})
                 usertable[uid]["data"]["courses"].sort(
                     key=lambda x: int(x["sections"][0]))  # 这里要对课表排序，否则打印课表时不会按时间顺序来
@@ -88,11 +90,11 @@ async def _(matcher: Matcher, bot: Bot, event: MessageEvent, key: str = ArgStr()
         if uid in userdata:  # 这里保存的是小爱课程表分享的链接，就可以定时通过这里的链接更新本地课表，但是还不清楚链接是否会失效
             userdata.update({uid: url})
             write_data()
-            await newtable.finish("你已经导入过课表了，咱帮你更新课表数据了", at_sender=True)
+            await newtable.finish("你已经导入过课表了喵，咱帮你更新课表数据了", at_sender=True)
         elif uid not in userdata:
             userdata.update({uid: url})
             write_data()
-            await newtable.finish("成功导入课表！快发送课表帮助来查看功能吧！", at_sender=True)
+            await newtable.finish("成功导入课表喵！快发送课表帮助来查看功能吧！", at_sender=True)
     else:
         await newtable.finish("出错了，请检查链接是否正确", at_sender=True)
 
@@ -101,10 +103,29 @@ async def _(matcher: Matcher, bot: Bot, event: MessageEvent, key: str = ArgStr()
 async def _(matcher: Matcher, bot: Bot, event: MessageEvent, key: str = RegexMatched()):
     uid = event.get_user_id()
     if uid not in userdata:
-        await someday_table.finish('你还没有导入课表，发送\\导入课表来导入吧！', at_sender=True)
+        await someday_table.finish('你还没有导入课表喵，发送\\导入课表来导入吧！', at_sender=True)
     else:
         await someday_table.finish(table_msg(key, uid), at_sender=True)
 
+@renew_table.handle()
+async def _(matcher:Matcher,bot:Bot,event:MessageEvent):
+    uid = event.get_user_id()
+    if uid not in userdata:
+        await renew_table.finish('你还没有导入课表喵，发送\\导入课表来导入吧！', at_sender=True)
+    else:
+        async with get_new_page(viewport={"width": 1000, "height": 1200}) as page:
+            page.on("response", lambda response: geturl(response))
+            await page.goto(userdata[uid], wait_until='networkidle')
+            global res_url
+            log_debug("response.url", res_url)
+            async with httpx.AsyncClient() as r:
+                res = await r.get(res_url)
+                usertable.update({uid: res.json()})
+                usertable[uid]["data"]["courses"].sort(
+                    key=lambda x: int(x["sections"][0]))  # 这里要对课表排序，否则打印课表时不会按时间顺序来
+                write_table()
+        await renew_table.finish("本地课表已更新喵！", at_sender=True)
+
 
 #-----------以下为定时任务----------------#
 @add_alock_someday.handle()
@@ -112,10 +133,12 @@ async def _(matcher: Matcher, bot: Bot, event: GroupMessageEvent, key: str = Reg
     uid = event.get_user_id()
     gid = event.group_id
     if uid not in userdata:
-        await add_alock_someday.finish('你还没有导入课表，发送\\导入课表来导入吧！', at_sender=True)
+        await add_alock_someday.finish('你还没有导入课表喵，发送\\导入课表来导入吧！', at_sender=True)
     else:
         if scheduler:
             send_day = (weekday_int(key)+5) % 7
+            if scheduler.get_job(str(uid+"post_alock"+str(send_day))):
+                await add_alock_someday.finish("出错了喵！你好像已经订阅过这天的课表了呢", at_sender=True)
             scheduler.add_job(post_alock, "cron", hour=22, id=str(
                 uid+"post_alock"+str(send_day)), args=[key, uid, gid], day_of_week=send_day)
             await add_alock_someday.finish("定时提醒添加成功！", at_sender=True)
@@ -123,10 +146,10 @@ async def _(matcher: Matcher, bot: Bot, event: GroupMessageEvent, key: str = Reg
             await add_alock_someday.finish("apscheduler插件未载入，无法添加定时提醒", at_sender=True)
 
 
+
 @remove_alock_someday.handle()
 async def _(matcher: Matcher, bot: Bot, event: GroupMessageEvent, key: str = RegexMatched()):
     uid = event.get_user_id()
-    gid = event.group_id
     if uid not in userdata:
         await add_alock_someday.finish('你还没有导入课表，发送\\导入课表来导入吧！', at_sender=True)
     else:
@@ -140,6 +163,20 @@ async def _(matcher: Matcher, bot: Bot, event: GroupMessageEvent, key: str = Reg
         else:
             await remove_alock_someday.finish("apscheduler插件未载入，无法删除定时提醒", at_sender=True)
 
+@add_alock_morningcalss.handle()
+async def _(matcher:Matcher,bot:Bot,event:GroupMessageEvent):
+    uid=event.get_user_id()
+    gid = event.group_id
+    if uid not in userdata:
+        await add_alock_morningcalss.finish('你还没有导入课表喵，发送\\导入课表来导入吧！', at_sender=True)
+    else:
+        if scheduler:
+            if scheduler.get_job(str(uid+"post_alock_morningclass")):
+                await add_alock_morningcalss.finish("出错了喵！你好像已经订阅过早八提醒了呢", at_sender=True)
+            scheduler.add_job(post_alock_morningclass, "cron", hour=20,id=str(uid+"post_alock_morningclass"), args=[uid, gid])
+            await add_alock_morningcalss.finish("定时提醒添加成功！", at_sender=True)
+        else:
+            await add_alock_morningcalss.finish("apscheduler插件未载入，无法添加定时提醒喵", at_sender=True)
 
 async def post_alock(*args):
     uid = args[1]
@@ -149,3 +186,28 @@ async def post_alock(*args):
         key = "明日课表"  # 发送周一课表时是周日，所以要发送的其实是明日课表
     msg = table_msg(key=key, uid=uid)
     await get_bot().send_group_msg(group_id=gid, message=MessageSegment.at(int(uid))+msg)
+
+
+async def post_alock_morningclass(*args):
+    uid=args[0]
+    gid=args[1]
+    someday=cn2an["明"]
+    someweek=int((time.time() - int(
+        usertable[uid]["data"]["setting"]['startSemester'][0:10]))//604800)
+    if someday==8:#星期天发送时时第二天是星期一，周数加1
+        someday=1
+        someweek=someweek+1  
+    count=0
+    msg="我来了喵!"
+    for i in range(len(usertable[uid]["data"]["courses"])):
+        if(usertable[uid]["data"]["courses"][i]["day"] == someday) and (str(someweek) in usertable[uid]["data"]["courses"][i]["weeks"].split(',')) and "1" in usertable[uid]["data"]["courses"][i]["sections"].split(","):
+            count+=1
+            msg+='\n'+usertable[uid]["data"]["courses"][i]["name"] + '\n@' + usertable[uid]["data"]["courses"][i]["position"]+'\n'+usertable[uid]["data"]["courses"][i]["teacher"]
+    if count==0:
+         msg+="\n你明天没有早八呢！享受夜生活吧！"
+    else:
+        msg+=f"\n你明天有{count}节早八呢！今晚早点休息吧！"
+    await get_bot().send_group_msg(group_id=gid, message=MessageSegment.at(int(uid))+msg)
+
+    
+
